@@ -15,15 +15,15 @@ class MyException(Exception):
     pass
 
 SETI_PRODUCTION= "https://api.seti.dev/v1/"
-SETI_DEVELOP ="http://localhost:5001/v1/"#"https://api-ve74dbrnra-uc.a.run.app/"
+SETI_DEVELOP = "https://api-ve74dbrnra-uc.a.run.app/"
 
 class Seti():
     
-    def __init__(self,path_to_private_key:str,api_key:str,public_key='',test=True) -> (None):
+    def __init__(self,path_to_private_key:str,api_key:str,public_key='',seti_path=SETI_DEVELOP) -> (None):
         self.private_key =path_to_private_key
         self.api_key= api_key
         self.public_key_loc = public_key
-        self.test=test
+        self.seti_path=seti_path
     
     def verify_sign(self,signature:str, data:dict):
         '''
@@ -62,7 +62,7 @@ class Seti():
         return b64encode(cipher_rsa.sign(hash)).decode("utf-8")
     
     def send_request(self,data:dict,sign_data:str,path:str):
-        url =   SETI_DEVELOP if self.test else  SETI_PRODUCTION
+        url = self.seti_path
         r = requests.post(url=url+path, json=data,headers={
             "authorization":self.api_key,
             "sign": sign_data
@@ -127,7 +127,6 @@ class Seti():
         encode_data = self.sign_data(data_create_wallet)
         return ResponseCreateWallet(self.send_request(data_create_wallet,encode_data,CREATE_WALLET_URL))
     
-    
     def validate_wallet(self,code:str,secret:str):
         data_validate_wallet = {
             "code": code,
@@ -137,7 +136,6 @@ class Seti():
         encode_data = self.sign_data(data_validate_wallet)
         return BasicResponse(self.send_request(data_validate_wallet,encode_data,VALIDATE_WALLET_URL))
     
-    
     def send_money_between_wallets(self,from_secret:str,to_secret:str,value:int):
         self.is_error = False
         self.validate_value(value)
